/***************************************************************************
 ArtAdmin: a simple app to administer your Linux Format articles database.
 Version: 0.9
 Written in Qt 4.3 

                           artadmin.cpp  -  description
                             -------------------
    copyright            : (C) 2007,2008 by Dimitris B. Kalamaras
    email                : dimitris.kalamaras@compupress.gr
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#include <QtGui>
#include "artadmin.h"
#include <QtSql>

ArtAdmin::ArtAdmin() {
        ui.setupUi(this);
	connect (ui.openAct,SIGNAL(triggered()), this,SLOT(loadFile()));
	connect (ui.quitAct,SIGNAL(triggered()), this,SLOT(close()));
	connect (ui.searchBt,SIGNAL(clicked()), this,SLOT(search()));
	connect (ui.clearBt,SIGNAL(clicked()), this,SLOT(clearAll()));
	initModel(&model, "null");
	QTableView *view1 = initTableView(QObject::tr("Database"), &model);
	view1->show();
	this->setWindowTitle("ArtAdmin - Greek Linux Format article catalogue");
	this->resize(800,600);
	ui.tabWidget->setCurrentIndex(0);
/*	//Χρήσιμες εντολές για Ελληνικά στην κονσόλα της MySQL - δεν χρειάζονται στο ArtAdmin.
	query.prepare("SET NAMES utf8");
	query.prepare("SET CHARACTER SET utf8;");
	query.prepare("SET character_set_server=utf8;");
	if(!query.exec() ) {
		qDebug()<<"Couldnt execute this query3";
		return;
	}
*/
}



void ArtAdmin::loadFile() {
	QString fileName = QFileDialog::getOpenFileName(this, tr("Open File"), 0,tr("Text files (*.txt)"));
	if (fileName.isEmpty()) {
		QMessageBox::critical(this,"Failure", tr("No filename!"),"OK",0);
		return;
	}
	QFile file ( fileName );
	if ( ! file.open(QIODevice::ReadOnly )) return;
	QString str;
	QTextStream ts( &file );
	while ( !ts.atEnd() )   {
		str= ts.readLine();
		QStringList article = str.split("*");
		for (int i = 0; i < article.size(); ++i)
		          qDebug() << article.at(i) << "\t";
		query.prepare("insert into articles(id,  title, editor, issue, month, type, pages, summary) values ('', :title, :editor, :issue, :month, :type, :pages, :summary)");
		query.bindValue(":title", article.at(0).trimmed());
		query.bindValue(":editor", article.at(1).trimmed());
		query.bindValue(":issue", article.at(2).trimmed());
		query.bindValue(":month", article.at(3).trimmed());
		query.bindValue(":type", article.at(4).trimmed());
		query.bindValue(":pages", article.at(5).trimmed());
		query.bindValue(":summary", article.at(6).trimmed());
		if(!query.exec() ) {	
			QMessageBox::critical(this,"Failure", tr("Couldn't execute query!"),"OK",0);
			return;
		}
		filter="null";
		initModel(&model, filter);
	}
	QMessageBox::information(this,"Greek Linux Format - ArtAdmin", tr("File Loaded!"),"OK",0);
}

void ArtAdmin::clearAll(){
	qDebug()<<"\n Clear all";
	ui.titleLE->clear();
	ui.editorLE->clear();
	ui.issueLE->clear();
	ui.monthLE->clear();
	ui.typeLE->clear();
	ui.pagesLE->clear();
	ui.textBrowser->clear();
	initModel(&model, "null");	
}



void ArtAdmin::search() {	
	qDebug()<<"\nStart Search";
	QString searchkeys= ui.searchLE->text();
	qDebug()<<searchkeys;
	if (searchkeys.isEmpty()) {
		QMessageBox::critical(this,"Failure", tr("No search terms!"),"OK",0);
		return;
	}
	QString qstr="SELECT * FROM articles WHERE (editor) like (\"%"+ searchkeys +"%\") OR (title) like (\"%"+ searchkeys +"%\") OR (summary) like (\"%"+ searchkeys +"%\")";
	filter = "(editor) like (\"%"+ searchkeys +"%\") OR (title) like (\"%"+ searchkeys +"%\") OR (summary) like (\"%"+ searchkeys +"%\")";

	qDebug()<<qstr;
	
	query.prepare(qstr);
	if(!query.exec() ) {
		QMessageBox::critical(this,"Failure", tr("Couldn't execute search query!"),"OK",0);
		return;
	}
	else 
		while (query.next()) {
			ui.titleLE->insert(query.value(1).toString());
			ui.editorLE->insert(query.value(2).toString());
			ui.issueLE->insert(query.value(3).toString());
			ui.monthLE->insert(query.value(4).toString());
			ui.typeLE->insert(query.value(5).toString());
			ui.pagesLE->insert( query.value(6).toString());
			ui.textBrowser->setPlainText(query.value(7).toString());	
			break;
     		}
	initModel(&model, filter);
}




void ArtAdmin::initModel(QSqlTableModel *model, QString filter)  {
	model->setTable("articles");
	model->removeColumn(0);
	qDebug()<<"filter: "<< filter;
	if (filter!="null")
		model->setFilter(filter);
	model->select();
}


QTableView *ArtAdmin::initTableView(const QString &title, QSqlTableModel *model)  {
	ui.tableView->setModel(model);
	ui.tableView->setWindowTitle(title);
	return ui.tableView;
 }

